@@ -18,8 +18,9 @@ void CnfNewPush(WSCbase* object){
 	bool flagDown = Cnfvtog_Download->getStatus();
 	long encoding = ConvStrToEncoding(
 		Cnfcomb_Encoding->getProperty( WSNlabelString ) );
+	long skipArt = Cnfvsli_SkipArt->getProperty( WSNvalue );
 
-	gHeadLine.AddUrlList( name, url, flagDown, encoding );
+	gHeadLine.AddUrlList( name, url, flagDown, encoding, skipArt );
 
 	Cnfcomb_NameList->setProperty( WSNmenuItems, gUrl.GetList() );
 	Cnfcomb_NameList->setProperty( WSNlabelString, name );
