@@ -2,18 +2,7 @@
 #include <WSCfunctionList.h>
 #include <WSCbase.h>
 
-/**/
-
-#if 0
-@@@
-#include <stdlib.h>
-#include <stdio.h>
-
-#ifdef _WIN32
-#else /* _WIN32 */
-# include <unistd.h>
-#endif /* _WIN32 */
-#endif
+#include <WSDenv.h>
 
 /**/
 
@@ -29,7 +18,7 @@
 
 /**/
 
-#define CONFIG_FILE_NAME	".nnhl.cnf"
+const long gSkipArtMaxN = 1000;
 
 /**/
 
