@@ -8,14 +8,33 @@
 
 /**/
 
+const unsigned long gSpeedOffset = 10;
+const long gDefaultScrollLen = 2;
+const unsigned long gDefaultScrollSpeed = 400 / gSpeedOffset;
+const unsigned long gDefaultScrollWait = 4000 / gSpeedOffset;
+
+/**/
+
 #define CONF_FILE_NAME	".nnhl.conf"
 #define URL_FILE_NAME	".nnhl_url"
 
-#define STR_HEADER_CONF	"# Config file Version "
+#define STR_HEADER_CONF_0_1_0	"# Config file Version "
+#define STR_HEADER_CONF_0_1_1	\
+	"# nnhl - Net News HeadLine : Config file Version "
+#define STR_HEADER_CONF	STR_HEADER_CONF_0_1_1
+
+#define STR_HEADER_URL_0_1_0	"# URL list Version "
+#define STR_HEADER_URL_0_1_1	\
+	"# nnhl - Net News HeadLine : URL list Version "
+#define STR_HEADER_URL	STR_HEADER_URL_0_1_1
+
 #define STR_VERSION_CONF_0_1_0	"0.1.0"
+#define STR_VERSION_CONF_0_1_1	"0.1.1"
+#define STR_VERSION_CONF	STR_VERSION_CONF_0_1_1
 
-#define STR_HEADER_URL	"# URL list Version "
 #define STR_VERSION_URL_0_1_0	"0.1.0"
+#define STR_VERSION_URL_0_1_1	"0.1.1"
+#define STR_VERSION_URL	STR_VERSION_URL_0_1_1
 
 /**/
 
@@ -155,22 +174,17 @@ TListUrl gListUrl[] = {
 void CHeadLine::Init( void )
 {
 #if 1
-	ResetMessage( LANG_KIND_JAPANESE );
+	SetMessage( LANG_KIND_JAPANESE );
 #else
-	ResetMessage( LANG_KIND_ENGLISH );
+	SetMessage( LANG_KIND_ENGLISH );
 #endif
 
-	Maivlab_Art->setProperty( WSNlabelString, MesLabelArt );
-	Maivlab_Thr->setProperty( WSNlabelString, MesLabelThr );
-	Maivlab_Site->setProperty( WSNlabelString, MesLabelSite );
-	Maivbtn_PrevUrlBtn->setProperty( WSNlabelString, MesLabelSitePrev );
-	Maivbtn_NextUrlBtn->setProperty( WSNlabelString, MesLabelSiteNext );
-	Maivbtn_BarBtn->setProperty( WSNlabelString, MesLabelBar );
-
 	mHeadLineCurN = 0;
 	mHeadLineMaxN = 0;
 	mFlagDown = false;
 
+	mFlagDump = false;
+
 	mStrItem = "";
 
 	mWordIdx = 0;
@@ -182,6 +196,9 @@ void CHeadLine::Init( void )
 	mStrThreadSep.clear();
 	mStrThreadSep << mStrThreadSepWord << mStrWordSep;
 
+	SetScroll( gDefaultScrollLen,
+		gDefaultScrollSpeed, gDefaultScrollWait );
+
 	gUrl.Init();
 	if( !Load() )
 		ResetUrlList();
@@ -292,12 +309,10 @@ void CHeadLine::Update( long nSkip, bool flagForce )
 void CHeadLine::UpdateSub(
 	long nSkip, bool flagForce, bool flagResetSkip )
 {
-	long scrollLen = 2;
-
 	unsigned long n = Maivscr_ScrollBar->getProperty( WSNvalue );
 	unsigned long max_n = Maivscr_ScrollBar->getProperty( WSNmaximum );
 
-	if( flagForce || ((n + scrollLen) >= max_n) ){
+	if( flagForce || ((n + mScrollLen) >= max_n) ){
 		if( !flagResetSkip )
 			mSkipArtCount++;
 
@@ -309,14 +324,14 @@ void CHeadLine::UpdateSub(
 			max_n = 1;
 		Maivscr_ScrollBar->setProperty( WSNvalue, n );
 		Maivscr_ScrollBar->setProperty( WSNmaximum, max_n );
-		Maivscr_ScrollBar->setProperty( WSNsliderSize, scrollLen );
-		Maivscr_ScrollBar->setProperty( WSNincrement, scrollLen );
+		Maivscr_ScrollBar->setProperty( WSNsliderSize, mScrollLen );
+		Maivscr_ScrollBar->setProperty( WSNincrement, mScrollLen );
 		Maivscr_ScrollBar->setProperty( WSNpageIncrement,
-			scrollLen * 10 );
+			mScrollLen * 10 );
 
 		WaitTimer();
 	} else {
-		n += scrollLen;
+		n += mScrollLen;
 		Maivscr_ScrollBar->setProperty( WSNvalue, n );
 
 	}
@@ -614,6 +629,8 @@ bool CHeadLine::Swap( long n1, long n2 )
 	if( !gUrl.Swap( n1, n2 ) )
 		return false;
 
+	mFlagDump = true;
+
 	WSCstring *tmpStr = (WSCstring *)mStrHeadLine[n1];
 	mStrHeadLine[n1] = mStrHeadLine[n2];
 	mStrHeadLine[n2] = tmpStr;
@@ -631,6 +648,14 @@ bool CHeadLine::Swap( long n1, long n2 )
 
 /**/
 
+void CHeadLine::ResetConfigMisc( void )
+{
+	SetScroll( gDefaultScrollLen,
+		gDefaultScrollSpeed, gDefaultScrollWait );
+}
+
+/**/
+
 WSCstring CHeadLine::PickUp2ch( WSCstring html )
 {
 	WSCstring text;
@@ -739,6 +764,8 @@ WSCstring CHeadLine::PickUp2ch( WSCstring html )
 		html.deleteChars( 0, idxEnd );
 	}
 
+	SleepSec( 2 );
+
 	DelHtmlHref( &text );
 
 	DelHtmlTag( &text, "<font", "</font>" );
@@ -1033,11 +1060,54 @@ void CHeadLine::SetDownText( long n, WSCstring str )
 
 /**/
 
+void CHeadLine::SetScroll( long len, long speed, long wait )
+{
+	if( len > 0 )
+		mScrollLen = len;
+
+	if( speed > 0 ){
+		mScrollSpeed = speed;
+
+		Maivtim_MainTimer->setProperty(
+			WSNinterval, speed * gSpeedOffset );
+	}
+
+	if( wait > 0 ){
+		mScrollWait = wait;
+
+		Maivtim_BeginTimer->setProperty(
+			WSNinterval, wait * gSpeedOffset );
+	}
+}
+
+/**/
+
+long CHeadLine::GetScrollLen( void )
+{
+	return mScrollLen;
+}
+
+/**/
+
+long CHeadLine::GetScrollSpeed( void )
+{
+	return mScrollSpeed;
+}
+
+/**/
+
+long CHeadLine::GetScrollWait( void )
+{
+	return mScrollWait;
+}
+
+/**/
+
 bool CHeadLine::Save( void )
 {
 	bool ret = true;
 
-	if( !SaveConfig() )
+	if( !SaveMisc() )
 		ret = false;
 	if( !SaveUrl() )
 		ret = false;
@@ -1047,16 +1117,50 @@ bool CHeadLine::Save( void )
 
 /**/
 
-bool CHeadLine::SaveConfig( void )
+bool CHeadLine::SaveMisc( void )
 {
 	WSCstring str;
-	str << "\"\",\""
-		<< "\",\""
-		<< STR_HEADER_CONF STR_VERSION_CONF_0_1_0 << "\",\""
-		<< "\",\""
-		<< "\",\""
-		<< "\",\""
-		<< "\"\n";
+	str << STR_HEADER_CONF STR_VERSION_CONF << "\n";
+
+	str << "scroll_chars = " << GetScrollLen() << "\n";
+	str << "scroll_speed = " << GetScrollSpeed() << "\n";
+	str << "scroll_wait = " << GetScrollWait() << "\n";
+	str << "\n";
+
+	str << "language = " << ::GetLangKind() << "\n";
+	str << "\n";
+
+	short left, top, width, height;
+
+	left = MainWin->getProperty( WSNx );
+	top = MainWin->getProperty( WSNy );
+	width = MainWin->getProperty( WSNwidth );
+	height = MainWin->getProperty( WSNheight );
+	str << "main_win_left = " << left << "\n";
+	str << "main_win_top = " << top << "\n";
+	str << "main_win_width = " << width << "\n";
+	str << "main_win_height = " << height << "\n";
+	str << "\n";
+
+	left = Misdial_ConfigMisc->getProperty( WSNx );
+	top = Misdial_ConfigMisc->getProperty( WSNy );
+	width = Misdial_ConfigMisc->getProperty( WSNwidth );
+	height = Misdial_ConfigMisc->getProperty( WSNheight );
+	str << "misc_win_left = " << left << "\n";
+	str << "misc_win_top = " << top << "\n";
+	str << "misc_win_width = " << width << "\n";
+	str << "misc_win_height = " << height << "\n";
+	str << "\n";
+
+	left = Cnfdial_ConfigUrl->getProperty( WSNx );
+	top = Cnfdial_ConfigUrl->getProperty( WSNy );
+	width = Cnfdial_ConfigUrl->getProperty( WSNwidth );
+	height = Cnfdial_ConfigUrl->getProperty( WSNheight );
+	str << "url_win_left = " << left << "\n";
+	str << "url_win_top = " << top << "\n";
+	str << "url_win_width = " << width << "\n";
+	str << "url_win_height = " << height << "\n";
+	str << "\n";
 
 	WSCstring fileName = ConvHomeFileName( CONF_FILE_NAME );
 
@@ -1079,7 +1183,7 @@ bool CHeadLine::SaveUrl( void )
 	WSCstring str;
 	str << "\"\",\""
 		<< "\",\""
-		<< STR_HEADER_URL STR_VERSION_URL_0_1_0 << "\",\""
+		<< STR_HEADER_URL STR_VERSION_URL << "\",\""
 		<< "\",\""
 		<< "\",\""
 		<< "\",\""
@@ -1116,7 +1220,7 @@ bool CHeadLine::Load( void )
 {
 	bool ret = true;
 
-	if( !LoadConfig() )
+	if( !LoadMisc() )
 		ret = false;
 	if( !LoadUrl() )
 		ret = false;
@@ -1126,8 +1230,129 @@ bool CHeadLine::Load( void )
 
 /**/
 
-bool CHeadLine::LoadConfig( void )
+bool CHeadLine::LoadMisc( void )
 {
+	WSCstring fileName = ConvHomeFileName( CONF_FILE_NAME );
+
+	if( !WSGFcheckExistFile( fileName ) )
+		return false;
+
+	WSCstring *str = WSGFreadTextFile( fileName );
+	WSCstring ver = str->getWord( 0, "\n" );
+
+	if( ver.isExist(
+		STR_HEADER_CONF_0_1_0
+		STR_VERSION_CONF_0_1_0 )
+		> -1 )
+	{
+		;
+	} else if( CompareString( ver,
+		STR_HEADER_CONF_0_1_1
+		STR_VERSION_CONF_0_1_1 ) )
+	{
+		LoadMisc_0_1( fileName, str );
+	} else {
+		WSCstring mes;
+		mes << MesLoadVerError << "\n(" << fileName << ")";
+
+		PopupError( mes );
+		return false;
+	}
+
+	return true;
+}
+
+/**/
+
+bool CHeadLine::LoadMisc_0_1( WSCstring fileName, WSCstring *str )
+{
+	long strMaxLine = str->getWords( "\n" ) - 1;
+
+	for( long i = 1; i < strMaxLine; i++ ){
+		/* I split to lines. */
+
+		WSCstring line = str->getWord( i, "\n" );
+
+		line.delHeadSpace();
+		line.delTailSpace();
+
+		if( line[0] == '#' )
+			continue;
+		if( line.getChars() <= 0 )
+			continue;
+
+		/* I split to tokens. */
+
+		WSCstring id = line.getWord( 0, "=" );
+		WSCstring val = line.getWord( 1, "=" );
+
+		id.delHeadSpace();
+		id.delTailSpace();
+		val.delHeadSpace();
+		val.delTailSpace();
+
+		if( id.getChars() <= 0 ){
+			WSCstring mes;
+			mes << MesLoadMiscError << "\n";
+			mes << fileName << ": " << i << "\n";
+			mes << "\"" << line << "\"";
+
+			PopupError( mes );
+
+			return false;
+		}
+
+		long n = strtol( val, NULL, 10 );
+		if( CompareString( id, "language" ) ){
+			SetMessage( (ELangKind)n );
+
+		} else if( CompareString( id, "scroll_chars" ) ){
+			SetScroll( n, 0, 0 );
+		} else if( CompareString( id, "scroll_speed" ) ){
+			SetScroll( 0, n, 0 );
+		} else if( CompareString( id, "scroll_wait" ) ){
+			SetScroll( 0, 0, n );
+
+		} else if( CompareString( id, "main_win_left" ) ){
+			MainWin->setProperty( WSNx, n );
+		} else if( CompareString( id, "main_win_top" ) ){
+			MainWin->setProperty( WSNy, n );
+		} else if( CompareString( id, "main_win_width" ) ){
+			MainWin->setProperty( WSNwidth, n );
+		} else if( CompareString( id, "main_win_height" ) ){
+			MainWin->setProperty( WSNheight, n );
+
+		} else if( CompareString( id, "misc_win_left" ) ){
+			Misdial_ConfigMisc->setProperty( WSNx, n );
+		} else if( CompareString( id, "misc_win_top" ) ){
+			Misdial_ConfigMisc->setProperty( WSNy, n );
+		} else if( CompareString( id, "misc_win_width" ) ){
+			Misdial_ConfigMisc->setProperty( WSNwidth, n );
+		} else if( CompareString( id, "misc_win_height" ) ){
+			Misdial_ConfigMisc->setProperty( WSNheight, n );
+
+		} else if( CompareString( id, "url_win_left" ) ){
+			Cnfdial_ConfigUrl->setProperty( WSNx, n );
+		} else if( CompareString( id, "url_win_top" ) ){
+			Cnfdial_ConfigUrl->setProperty( WSNy, n );
+		} else if( CompareString( id, "url_win_width" ) ){
+			Cnfdial_ConfigUrl->setProperty( WSNwidth, n );
+		} else if( CompareString( id, "url_win_height" ) ){
+			Cnfdial_ConfigUrl->setProperty( WSNheight, n );
+
+		} else {
+			WSCstring mes;
+			mes << MesLoadMiscError << "\n";
+			mes << fileName << ": " << i << "\n";
+			mes << "ID: \"" << id << "\"" << "\n";
+			mes << "N: \"" << val << "\"" << "\n";
+
+			PopupError( mes );
+
+			return false;
+		}
+	}
+
 	return true;
 }
 
@@ -1146,11 +1371,21 @@ bool CHeadLine::LoadUrl( void )
 
 	DeleteUrlListAll();
 
-	if( CompareString( ver, STR_HEADER_URL STR_VERSION_URL_0_1_0 ) ){
-		LoadUrl_0_1( str );
+	if( CompareString( ver,
+		STR_HEADER_URL_0_1_0
+		STR_VERSION_URL_0_1_0 ) )
+	{
+		LoadUrl_0_1( fileName, str );
+	} else if( CompareString( ver,
+		STR_HEADER_URL_0_1_1
+		STR_VERSION_URL_0_1_1 ) )
+	{
+		LoadUrl_0_1( fileName, str );
 	} else {
 		WSCstring mes;
-		mes << MesLoadVerError << "\n(" << fileName << ")";
+		mes << MesLoadVerError << "\n";
+		mes << fileName << "\n";
+		mes << "\"" << ver << "\"";
 
 		PopupError( mes );
 		return false;
@@ -1161,7 +1396,7 @@ bool CHeadLine::LoadUrl( void )
 
 /**/
 
-bool CHeadLine::LoadUrl_0_1( WSCstring *str )
+bool CHeadLine::LoadUrl_0_1( WSCstring fileName, WSCstring *str )
 {
 	long strMaxLine = str->getWords( "\n" ) - 1;
 
@@ -1311,6 +1546,11 @@ void *BGDownLoad( void *arg )
 
 		/* Finish. */
 
+		if( hl.mFlagDump ){
+			hl.mFlagDump = false;
+			continue;
+		}
+
 		hl.SetDone( curN, true );
 		hl.mFlagDown = true;
 
