@@ -14,6 +14,8 @@ private:
 	long mDownN;
 	WSCstring mStrDown;
 
+	bool mFlagDump;
+
 	WSClistData mStrHeadLine;
 	WSClistData mFlagDone;
 	WSCstring mStrItem;
@@ -22,6 +24,10 @@ private:
 	long mWordMaxIdx;
 	long mSkipArtCount;
 
+	long mScrollLen;
+	long mScrollSpeed;
+	long mScrollWait;
+
 	WSCstring mStrWordSep;
 	WSCstring mStrThreadSepWord;
 	WSCstring mStrThreadSep;
@@ -68,13 +74,21 @@ public:
 	void CHeadLine::DeleteUrlListAll( void );
 	bool CHeadLine::Swap( long n1, long n2 );
 
+	void CHeadLine::ResetConfigMisc( void );
+
+	void CHeadLine::SetScroll( long len, long speed, long wait );
+	long CHeadLine::GetScrollLen( void );
+	long CHeadLine::GetScrollSpeed( void );
+	long CHeadLine::GetScrollWait( void );
+
 	bool CHeadLine::Save( void );
-	bool CHeadLine::SaveConfig( void );
+	bool CHeadLine::SaveMisc( void );
 	bool CHeadLine::SaveUrl( void );
 	bool CHeadLine::Load( void );
-	bool CHeadLine::LoadConfig( void );
+	bool CHeadLine::LoadMisc( void );
+	bool CHeadLine::LoadMisc_0_1( WSCstring fileName, WSCstring *str );
 	bool CHeadLine::LoadUrl( void );
-	bool CHeadLine::LoadUrl_0_1( WSCstring *str );
+	bool CHeadLine::LoadUrl_0_1( WSCstring fileName, WSCstring *str );
 private:
 	void CHeadLine::UpdateSub(
 		long nSkip, bool flagForce, bool flagResetSkip );
