@@ -21,9 +21,9 @@ void MainMenuCnfUrl(WSCbase* object){
 	long n = Cnfdial_ConfigUrl->popup();
 
 	if( n == WS_DIALOG_OK ){
-		gHeadLine.Save();
+		gHeadLine.SaveUrl();
 	} else {
-		if( !gHeadLine.Load() )
+		if( !gHeadLine.LoadUrl() )
 			gHeadLine.ResetUrlList();
 	}
 }
