@@ -64,6 +64,18 @@ WSCvlabel* Cnfvlab_SkipArt;
 WSCvslider* Cnfvsli_SkipArt;
 WSCvifield* Cnfvifi_SkipArt;
 WSCvtimer* Maivtim_ReloadTimer;
+WSCdialog* Misdial_ConfigMisc;
+WSCvlabel* Misvlab_Chars;
+WSCvifield* Misvifi_Chars;
+WSCvslider* Misvsli_Chars;
+WSCvlabel* Misvlab_Speed;
+WSCvifield* Misvifi_Speed;
+WSCvslider* Misvsli_Speed;
+WSCvlabel* Misvlab_Wait;
+WSCvifield* Misvifi_Wait;
+WSCvslider* Misvsli_Wait;
+WSCcomboBox* Miscomb_Language;
+WSCvlabel* Misvlab_Language;
 
 //--- OBJECT src ---//
 
@@ -76,8 +88,8 @@ WSCbase* _create_win_MainWin(){
   MainWin->setPropertyV(WSNtitleString,"News Head Line");
   MainWin->setPropertyV(WSNx,(short)100);
   MainWin->setPropertyV(WSNy,(short)100);
-  MainWin->setPropertyV(WSNwidth,(unsigned short)669);
-  MainWin->setPropertyV(WSNheight,(unsigned short)245);
+  MainWin->setPropertyV(WSNwidth,(unsigned short)640);
+  MainWin->setPropertyV(WSNheight,(unsigned short)240);
   MainWin->setPropertyV(WSNbackColor,"#dcdcdc");
   MainWin->setPropertyV(WSNtopShadowColor,"#ffffff");
   MainWin->setPropertyV(WSNbottomShadowColor,"#b4b4b4");
@@ -90,6 +102,10 @@ WSCbase* _create_win_MainWin(){
     extern void MainWinFixSize(WSCbase*);
     op_MainWin_6->setFunction(MainWinFixSize,"MainWinFixSize");
     MainWin->addProcedure(op_MainWin_6);
+    WSCprocedure* op_MainWin_7 = new WSCprocedure("MainWinExit",32);
+    extern void MainWinExit(WSCbase*);
+    op_MainWin_7->setFunction(MainWinExit,"MainWinExit");
+    MainWin->addProcedure(op_MainWin_7);
 
   Maivksl_HeadLine = new  WSCvkslabel(MainWin,"Maivksl_HeadLine");
       Maivksl_HeadLine->initialize();
@@ -99,7 +115,7 @@ WSCbase* _create_win_MainWin(){
   Maivksl_HeadLine->setPropertyV(WSNvis,(WSCbool)1);
   Maivksl_HeadLine->setPropertyV(WSNx,(short)20);
   Maivksl_HeadLine->setPropertyV(WSNy,(short)100);
-  Maivksl_HeadLine->setPropertyV(WSNwidth,(unsigned short)629);
+  Maivksl_HeadLine->setPropertyV(WSNwidth,(unsigned short)600);
   Maivksl_HeadLine->setPropertyV(WSNanchorTop,(unsigned short)100);
   Maivksl_HeadLine->setPropertyV(WSNanchorBottom,(unsigned short)20);
   Maivksl_HeadLine->setPropertyV(WSNanchorLeft,(unsigned short)20);
@@ -143,7 +159,7 @@ WSCbase* _create_win_MainWin(){
   Maivscr_ScrollBar->setPropertyV(WSNvis,(WSCbool)1);
   Maivscr_ScrollBar->setPropertyV(WSNx,(short)20);
   Maivscr_ScrollBar->setPropertyV(WSNy,(short)130);
-  Maivscr_ScrollBar->setPropertyV(WSNwidth,(unsigned short)629);
+  Maivscr_ScrollBar->setPropertyV(WSNwidth,(unsigned short)600);
   Maivscr_ScrollBar->setPropertyV(WSNheight,(unsigned short)20);
   Maivscr_ScrollBar->setPropertyV(WSNanchorTop,(unsigned short)130);
   Maivscr_ScrollBar->setPropertyV(WSNanchorBottom,(unsigned short)20);
@@ -193,7 +209,7 @@ WSCbase* _create_win_MainWin(){
   Maicomb_NameList->setPropertyV(WSNname,"Maicomb_NameList");
   Maicomb_NameList->setPropertyV(WSNx,(short)20);
   Maicomb_NameList->setPropertyV(WSNy,(short)50);
-  Maicomb_NameList->setPropertyV(WSNwidth,(unsigned short)629);
+  Maicomb_NameList->setPropertyV(WSNwidth,(unsigned short)600);
   Maicomb_NameList->setPropertyV(WSNvis,(WSCbool)1);
   Maicomb_NameList->setPropertyV(WSNanchorTop,(unsigned short)50);
   Maicomb_NameList->setPropertyV(WSNanchorLeft,(unsigned short)20);
@@ -212,7 +228,7 @@ WSCbase* _create_win_MainWin(){
   Maivbtn_StopBtn->setPropertyV(WSNlabelString,"||");
   Maivbtn_StopBtn->setPropertyV(WSNname,"Maivbtn_StopBtn");
   Maivbtn_StopBtn->setPropertyV(WSNvis,(WSCbool)1);
-  Maivbtn_StopBtn->setPropertyV(WSNx,(short)269);
+  Maivbtn_StopBtn->setPropertyV(WSNx,(short)240);
   Maivbtn_StopBtn->setPropertyV(WSNy,(short)150);
   Maivbtn_StopBtn->setPropertyV(WSNwidth,(unsigned short)50);
   Maivbtn_StopBtn->setPropertyV(WSNanchorTop,(unsigned short)150);
@@ -230,7 +246,7 @@ WSCbase* _create_win_MainWin(){
   Maivbtn_NextUrlBtn->setPropertyV(WSNlabelString,"NEXT");
   Maivbtn_NextUrlBtn->setPropertyV(WSNname,"Maivbtn_NextUrlBtn");
   Maivbtn_NextUrlBtn->setPropertyV(WSNvis,(WSCbool)1);
-  Maivbtn_NextUrlBtn->setPropertyV(WSNx,(short)379);
+  Maivbtn_NextUrlBtn->setPropertyV(WSNx,(short)350);
   Maivbtn_NextUrlBtn->setPropertyV(WSNy,(short)150);
   Maivbtn_NextUrlBtn->setPropertyV(WSNwidth,(unsigned short)50);
   Maivbtn_NextUrlBtn->setPropertyV(WSNanchorTop,(unsigned short)150);
@@ -248,7 +264,7 @@ WSCbase* _create_win_MainWin(){
   Maivbtn_PrevUrlBtn->setPropertyV(WSNlabelString,"PREV");
   Maivbtn_PrevUrlBtn->setPropertyV(WSNname,"Maivbtn_PrevUrlBtn");
   Maivbtn_PrevUrlBtn->setPropertyV(WSNvis,(WSCbool)1);
-  Maivbtn_PrevUrlBtn->setPropertyV(WSNx,(short)329);
+  Maivbtn_PrevUrlBtn->setPropertyV(WSNx,(short)300);
   Maivbtn_PrevUrlBtn->setPropertyV(WSNy,(short)150);
   Maivbtn_PrevUrlBtn->setPropertyV(WSNwidth,(unsigned short)50);
   Maivbtn_PrevUrlBtn->setPropertyV(WSNanchorTop,(unsigned short)150);
@@ -266,7 +282,7 @@ WSCbase* _create_win_MainWin(){
   Maivbtn_NextArtBtn->setPropertyV(WSNlabelString,">|");
   Maivbtn_NextArtBtn->setPropertyV(WSNname,"Maivbtn_NextArtBtn");
   Maivbtn_NextArtBtn->setPropertyV(WSNvis,(WSCbool)1);
-  Maivbtn_NextArtBtn->setPropertyV(WSNx,(short)599);
+  Maivbtn_NextArtBtn->setPropertyV(WSNx,(short)570);
   Maivbtn_NextArtBtn->setPropertyV(WSNy,(short)150);
   Maivbtn_NextArtBtn->setPropertyV(WSNwidth,(unsigned short)50);
   Maivbtn_NextArtBtn->setPropertyV(WSNanchorTop,(unsigned short)150);
@@ -284,7 +300,7 @@ WSCbase* _create_win_MainWin(){
   Maivbtn_PrevArtBtn->setPropertyV(WSNlabelString,"|<");
   Maivbtn_PrevArtBtn->setPropertyV(WSNname,"Maivbtn_PrevArtBtn");
   Maivbtn_PrevArtBtn->setPropertyV(WSNvis,(WSCbool)1);
-  Maivbtn_PrevArtBtn->setPropertyV(WSNx,(short)549);
+  Maivbtn_PrevArtBtn->setPropertyV(WSNx,(short)520);
   Maivbtn_PrevArtBtn->setPropertyV(WSNy,(short)150);
   Maivbtn_PrevArtBtn->setPropertyV(WSNwidth,(unsigned short)50);
   Maivbtn_PrevArtBtn->setPropertyV(WSNanchorTop,(unsigned short)150);
@@ -302,7 +318,7 @@ WSCbase* _create_win_MainWin(){
   Maivlab_Art->setPropertyV(WSNlabelString,"ARTICLE");
   Maivlab_Art->setPropertyV(WSNname,"Maivlab_Art");
   Maivlab_Art->setPropertyV(WSNvis,(WSCbool)1);
-  Maivlab_Art->setPropertyV(WSNx,(short)549);
+  Maivlab_Art->setPropertyV(WSNx,(short)520);
   Maivlab_Art->setPropertyV(WSNy,(short)180);
   Maivlab_Art->setPropertyV(WSNanchorTop,(unsigned short)180);
   Maivlab_Art->setPropertyV(WSNanchorRight,(unsigned short)20);
@@ -315,7 +331,7 @@ WSCbase* _create_win_MainWin(){
   Maivlab_Thr->setPropertyV(WSNlabelString,"THREAD");
   Maivlab_Thr->setPropertyV(WSNname,"Maivlab_Thr");
   Maivlab_Thr->setPropertyV(WSNvis,(WSCbool)1);
-  Maivlab_Thr->setPropertyV(WSNx,(short)439);
+  Maivlab_Thr->setPropertyV(WSNx,(short)410);
   Maivlab_Thr->setPropertyV(WSNy,(short)180);
   Maivlab_Thr->setPropertyV(WSNanchorTop,(unsigned short)180);
   Maivlab_Thr->setPropertyV(WSNanchorRight,(unsigned short)130);
@@ -328,7 +344,7 @@ WSCbase* _create_win_MainWin(){
   Maivbtn_NextThrBtn->setPropertyV(WSNlabelString,">>|");
   Maivbtn_NextThrBtn->setPropertyV(WSNname,"Maivbtn_NextThrBtn");
   Maivbtn_NextThrBtn->setPropertyV(WSNvis,(WSCbool)1);
-  Maivbtn_NextThrBtn->setPropertyV(WSNx,(short)489);
+  Maivbtn_NextThrBtn->setPropertyV(WSNx,(short)460);
   Maivbtn_NextThrBtn->setPropertyV(WSNy,(short)150);
   Maivbtn_NextThrBtn->setPropertyV(WSNwidth,(unsigned short)50);
   Maivbtn_NextThrBtn->setPropertyV(WSNanchorTop,(unsigned short)150);
@@ -346,7 +362,7 @@ WSCbase* _create_win_MainWin(){
   Maivbtn_PrevThrBtn->setPropertyV(WSNlabelString,"|<<");
   Maivbtn_PrevThrBtn->setPropertyV(WSNname,"Maivbtn_PrevThrBtn");
   Maivbtn_PrevThrBtn->setPropertyV(WSNvis,(WSCbool)1);
-  Maivbtn_PrevThrBtn->setPropertyV(WSNx,(short)439);
+  Maivbtn_PrevThrBtn->setPropertyV(WSNx,(short)410);
   Maivbtn_PrevThrBtn->setPropertyV(WSNy,(short)150);
   Maivbtn_PrevThrBtn->setPropertyV(WSNwidth,(unsigned short)50);
   Maivbtn_PrevThrBtn->setPropertyV(WSNanchorTop,(unsigned short)150);
@@ -364,7 +380,7 @@ WSCbase* _create_win_MainWin(){
   Maivlab_Site->setPropertyV(WSNlabelString,"SITE");
   Maivlab_Site->setPropertyV(WSNname,"Maivlab_Site");
   Maivlab_Site->setPropertyV(WSNvis,(WSCbool)1);
-  Maivlab_Site->setPropertyV(WSNx,(short)329);
+  Maivlab_Site->setPropertyV(WSNx,(short)300);
   Maivlab_Site->setPropertyV(WSNy,(short)180);
   Maivlab_Site->setPropertyV(WSNanchorTop,(unsigned short)180);
   Maivlab_Site->setPropertyV(WSNanchorRight,(unsigned short)240);
@@ -377,7 +393,7 @@ WSCbase* _create_win_MainWin(){
   Maivbtn_BarBtn->setPropertyV(WSNlabelString,"BAR");
   Maivbtn_BarBtn->setPropertyV(WSNname,"Maivbtn_BarBtn");
   Maivbtn_BarBtn->setPropertyV(WSNvis,(WSCbool)1);
-  Maivbtn_BarBtn->setPropertyV(WSNx,(short)209);
+  Maivbtn_BarBtn->setPropertyV(WSNx,(short)180);
   Maivbtn_BarBtn->setPropertyV(WSNy,(short)150);
   Maivbtn_BarBtn->setPropertyV(WSNwidth,(unsigned short)50);
   Maivbtn_BarBtn->setPropertyV(WSNanchorTop,(unsigned short)150);
@@ -407,7 +423,7 @@ WSCbase* _create_win_MainWin(){
   Maimenu_MainMenu->setPropertyV(WSNname,"Maimenu_MainMenu");
   Maimenu_MainMenu->setPropertyV(WSNx,(short)0);
   Maimenu_MainMenu->setPropertyV(WSNy,(short)0);
-  Maimenu_MainMenu->setPropertyV(WSNwidth,(unsigned short)669);
+  Maimenu_MainMenu->setPropertyV(WSNwidth,(unsigned short)640);
   Maimenu_MainMenu->setPropertyV(WSNvis,(WSCbool)1);
   Maimenu_MainMenu->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
   Maimenu_MainMenu->setPropertyV(WSNanchorRightFlag,(WSCbool)1);
@@ -428,7 +444,7 @@ WSCbase* _create_win_MainWin(){
 
   Maipull_MainMenuOpt = new  WSCpulldownMenu(Maimenu_MainMenu,"Maipull_MainMenuOpt");
       Maipull_MainMenuOpt->initialize();
-  Maipull_MainMenuOpt->setPropertyV(WSNmenuItems,"Config URL(U):MainMenuCnfUrl:U:1");
+  Maipull_MainMenuOpt->setPropertyV(WSNmenuItems,"Config URL(U):MainMenuCnfUrl:U:1,Config(C):MainMenuCnfMisc:C:2");
   Maipull_MainMenuOpt->setPropertyV(WSNshortcut,"O");
   Maipull_MainMenuOpt->setPropertyV(WSNusePixmap,(WSCbool)1);
   Maipull_MainMenuOpt->setPropertyV(WSNlabelString,"Option(O)");
@@ -440,6 +456,10 @@ WSCbase* _create_win_MainWin(){
     extern void MainMenuCnfUrl(WSCbase*);
     op_Maipull_MainMenuOpt_5->setFunction(MainMenuCnfUrl,"MainMenuCnfUrl");
     Maipull_MainMenuOpt->addProcedure(op_Maipull_MainMenuOpt_5);
+    WSCprocedure* op_Maipull_MainMenuOpt_6 = new WSCprocedure("MainMenuCnfMisc",-1);
+    extern void MainMenuCnfMisc(WSCbase*);
+    op_Maipull_MainMenuOpt_6->setFunction(MainMenuCnfMisc,"MainMenuCnfMisc");
+    Maipull_MainMenuOpt->addProcedure(op_Maipull_MainMenuOpt_6);
 
   Cnfdial_ConfigUrl = new  WSCdialog(MainWin,"Cnfdial_ConfigUrl");
       Cnfdial_ConfigUrl->initialize();
@@ -746,10 +766,10 @@ WSCbase* _create_win_MainWin(){
 
   Cnfvsli_SkipArt = new  WSCvslider(Cnfdial_ConfigUrl,"Cnfvsli_SkipArt");
       Cnfvsli_SkipArt->initialize();
-  Cnfvsli_SkipArt->setPropertyV(WSNsliderSize,(unsigned short)10);
+  Cnfvsli_SkipArt->setPropertyV(WSNsliderSize,(unsigned short)20);
   Cnfvsli_SkipArt->setPropertyV(WSNminimum,(short)1);
   Cnfvsli_SkipArt->setPropertyV(WSNdragInterval,(unsigned short)1);
-  Cnfvsli_SkipArt->setPropertyV(WSNvalue,(short)1000);
+  Cnfvsli_SkipArt->setPropertyV(WSNvalue,(short)992);
   Cnfvsli_SkipArt->setPropertyV(WSNname,"Cnfvsli_SkipArt");
   Cnfvsli_SkipArt->setPropertyV(WSNvis,(WSCbool)1);
   Cnfvsli_SkipArt->setPropertyV(WSNx,(short)320);
@@ -794,6 +814,211 @@ WSCbase* _create_win_MainWin(){
     op_Maivtim_ReloadTimer_5->setFunction(ReloadTimerUpdate,"ReloadTimerUpdate");
     Maivtim_ReloadTimer->addProcedure(op_Maivtim_ReloadTimer_5);
 
+  Misdial_ConfigMisc = new  WSCdialog(MainWin,"Misdial_ConfigMisc");
+      Misdial_ConfigMisc->initialize();
+  Misdial_ConfigMisc->setPropertyV(WSNno,(WSCbool)0);
+  Misdial_ConfigMisc->setPropertyV(WSNname,"Misdial_ConfigMisc");
+  Misdial_ConfigMisc->setPropertyV(WSNtitleString,"title1");
+  Misdial_ConfigMisc->setPropertyV(WSNx,(short)100);
+  Misdial_ConfigMisc->setPropertyV(WSNy,(short)100);
+  Misdial_ConfigMisc->setPropertyV(WSNwidth,(unsigned short)500);
+  Misdial_ConfigMisc->setPropertyV(WSNheight,(unsigned short)240);
+    WSCprocedure* op_Misdial_ConfigMisc_5 = new WSCprocedure("MisWinInit",0);
+    extern void MisWinInit(WSCbase*);
+    op_Misdial_ConfigMisc_5->setFunction(MisWinInit,"MisWinInit");
+    Misdial_ConfigMisc->addProcedure(op_Misdial_ConfigMisc_5);
+    WSCprocedure* op_Misdial_ConfigMisc_6 = new WSCprocedure("MisWinPush",2);
+    extern void MisWinPush(WSCbase*);
+    op_Misdial_ConfigMisc_6->setFunction(MisWinPush,"MisWinPush");
+    Misdial_ConfigMisc->addProcedure(op_Misdial_ConfigMisc_6);
+
+  Misvlab_Chars = new  WSCvlabel(Misdial_ConfigMisc,"Misvlab_Chars");
+      Misvlab_Chars->initialize();
+  Misvlab_Chars->setPropertyV(WSNusePixmap,(WSCbool)1);
+  Misvlab_Chars->setPropertyV(WSNlabelString,"Scroll characters");
+  Misvlab_Chars->setPropertyV(WSNname,"Misvlab_Chars");
+  Misvlab_Chars->setPropertyV(WSNvis,(WSCbool)1);
+  Misvlab_Chars->setPropertyV(WSNx,(short)20);
+  Misvlab_Chars->setPropertyV(WSNy,(short)20);
+  Misvlab_Chars->setPropertyV(WSNwidth,(unsigned short)200);
+  Misvlab_Chars->setPropertyV(WSNanchorTop,(unsigned short)20);
+  Misvlab_Chars->setPropertyV(WSNanchorLeft,(unsigned short)20);
+  Misvlab_Chars->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
+  Misvlab_Chars->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
+
+  Misvifi_Chars = new  WSCvifield(Misdial_ConfigMisc,"Misvifi_Chars");
+      Misvifi_Chars->initialize();
+  Misvifi_Chars->setPropertyV(WSNusePixmap,(WSCbool)1);
+  Misvifi_Chars->setPropertyV(WSNname,"Misvifi_Chars");
+  Misvifi_Chars->setPropertyV(WSNvis,(WSCbool)1);
+  Misvifi_Chars->setPropertyV(WSNx,(short)220);
+  Misvifi_Chars->setPropertyV(WSNy,(short)20);
+  Misvifi_Chars->setPropertyV(WSNanchorTop,(unsigned short)20);
+  Misvifi_Chars->setPropertyV(WSNanchorLeft,(unsigned short)220);
+  Misvifi_Chars->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
+  Misvifi_Chars->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
+    WSCprocedure* op_Misvifi_Chars_5 = new WSCprocedure("MisCharsIfiChg",3);
+    extern void MisCharsIfiChg(WSCbase*);
+    op_Misvifi_Chars_5->setFunction(MisCharsIfiChg,"MisCharsIfiChg");
+    Misvifi_Chars->addProcedure(op_Misvifi_Chars_5);
+
+  Misvsli_Chars = new  WSCvslider(Misdial_ConfigMisc,"Misvsli_Chars");
+      Misvsli_Chars->initialize();
+  Misvsli_Chars->setPropertyV(WSNsliderSize,(unsigned short)20);
+  Misvsli_Chars->setPropertyV(WSNmaximum,(short)100);
+  Misvsli_Chars->setPropertyV(WSNminimum,(short)1);
+  Misvsli_Chars->setPropertyV(WSNdragInterval,(unsigned short)1);
+  Misvsli_Chars->setPropertyV(WSNvalue,(short)12);
+  Misvsli_Chars->setPropertyV(WSNname,"Misvsli_Chars");
+  Misvsli_Chars->setPropertyV(WSNvis,(WSCbool)1);
+  Misvsli_Chars->setPropertyV(WSNx,(short)320);
+  Misvsli_Chars->setPropertyV(WSNy,(short)20);
+  Misvsli_Chars->setPropertyV(WSNwidth,(unsigned short)160);
+  Misvsli_Chars->setPropertyV(WSNanchorTop,(unsigned short)20);
+  Misvsli_Chars->setPropertyV(WSNanchorLeft,(unsigned short)320);
+  Misvsli_Chars->setPropertyV(WSNanchorRight,(unsigned short)20);
+  Misvsli_Chars->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
+  Misvsli_Chars->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
+  Misvsli_Chars->setPropertyV(WSNanchorRightFlag,(WSCbool)1);
+    WSCprocedure* op_Misvsli_Chars_5 = new WSCprocedure("MisCharsSliChg",3);
+    extern void MisCharsSliChg(WSCbase*);
+    op_Misvsli_Chars_5->setFunction(MisCharsSliChg,"MisCharsSliChg");
+    Misvsli_Chars->addProcedure(op_Misvsli_Chars_5);
+
+  Misvlab_Speed = new  WSCvlabel(Misdial_ConfigMisc,"Misvlab_Speed");
+      Misvlab_Speed->initialize();
+  Misvlab_Speed->setPropertyV(WSNusePixmap,(WSCbool)1);
+  Misvlab_Speed->setPropertyV(WSNlabelString,"Scroll speed");
+  Misvlab_Speed->setPropertyV(WSNname,"Misvlab_Speed");
+  Misvlab_Speed->setPropertyV(WSNvis,(WSCbool)1);
+  Misvlab_Speed->setPropertyV(WSNx,(short)20);
+  Misvlab_Speed->setPropertyV(WSNy,(short)60);
+  Misvlab_Speed->setPropertyV(WSNwidth,(unsigned short)200);
+  Misvlab_Speed->setPropertyV(WSNanchorTop,(unsigned short)60);
+  Misvlab_Speed->setPropertyV(WSNanchorLeft,(unsigned short)20);
+  Misvlab_Speed->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
+  Misvlab_Speed->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
+
+  Misvifi_Speed = new  WSCvifield(Misdial_ConfigMisc,"Misvifi_Speed");
+      Misvifi_Speed->initialize();
+  Misvifi_Speed->setPropertyV(WSNusePixmap,(WSCbool)1);
+  Misvifi_Speed->setPropertyV(WSNname,"Misvifi_Speed");
+  Misvifi_Speed->setPropertyV(WSNvis,(WSCbool)1);
+  Misvifi_Speed->setPropertyV(WSNx,(short)220);
+  Misvifi_Speed->setPropertyV(WSNy,(short)60);
+  Misvifi_Speed->setPropertyV(WSNanchorTop,(unsigned short)60);
+  Misvifi_Speed->setPropertyV(WSNanchorLeft,(unsigned short)220);
+  Misvifi_Speed->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
+  Misvifi_Speed->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
+    WSCprocedure* op_Misvifi_Speed_5 = new WSCprocedure("MisSpeedIfiChg",3);
+    extern void MisSpeedIfiChg(WSCbase*);
+    op_Misvifi_Speed_5->setFunction(MisSpeedIfiChg,"MisSpeedIfiChg");
+    Misvifi_Speed->addProcedure(op_Misvifi_Speed_5);
+
+  Misvsli_Speed = new  WSCvslider(Misdial_ConfigMisc,"Misvsli_Speed");
+      Misvsli_Speed->initialize();
+  Misvsli_Speed->setPropertyV(WSNsliderSize,(unsigned short)20);
+  Misvsli_Speed->setPropertyV(WSNminimum,(short)1);
+  Misvsli_Speed->setPropertyV(WSNdragInterval,(unsigned short)1);
+  Misvsli_Speed->setPropertyV(WSNvalue,(short)22);
+  Misvsli_Speed->setPropertyV(WSNname,"Misvsli_Speed");
+  Misvsli_Speed->setPropertyV(WSNvis,(WSCbool)1);
+  Misvsli_Speed->setPropertyV(WSNx,(short)320);
+  Misvsli_Speed->setPropertyV(WSNy,(short)60);
+  Misvsli_Speed->setPropertyV(WSNwidth,(unsigned short)160);
+  Misvsli_Speed->setPropertyV(WSNanchorTop,(unsigned short)60);
+  Misvsli_Speed->setPropertyV(WSNanchorLeft,(unsigned short)320);
+  Misvsli_Speed->setPropertyV(WSNanchorRight,(unsigned short)20);
+  Misvsli_Speed->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
+  Misvsli_Speed->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
+  Misvsli_Speed->setPropertyV(WSNanchorRightFlag,(WSCbool)1);
+    WSCprocedure* op_Misvsli_Speed_5 = new WSCprocedure("MisSpeedSliChg",3);
+    extern void MisSpeedSliChg(WSCbase*);
+    op_Misvsli_Speed_5->setFunction(MisSpeedSliChg,"MisSpeedSliChg");
+    Misvsli_Speed->addProcedure(op_Misvsli_Speed_5);
+
+  Misvlab_Wait = new  WSCvlabel(Misdial_ConfigMisc,"Misvlab_Wait");
+      Misvlab_Wait->initialize();
+  Misvlab_Wait->setPropertyV(WSNusePixmap,(WSCbool)1);
+  Misvlab_Wait->setPropertyV(WSNlabelString,"Wait");
+  Misvlab_Wait->setPropertyV(WSNname,"Misvlab_Wait");
+  Misvlab_Wait->setPropertyV(WSNvis,(WSCbool)1);
+  Misvlab_Wait->setPropertyV(WSNx,(short)20);
+  Misvlab_Wait->setPropertyV(WSNy,(short)100);
+  Misvlab_Wait->setPropertyV(WSNwidth,(unsigned short)200);
+  Misvlab_Wait->setPropertyV(WSNanchorTop,(unsigned short)100);
+  Misvlab_Wait->setPropertyV(WSNanchorLeft,(unsigned short)20);
+  Misvlab_Wait->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
+  Misvlab_Wait->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
+
+  Misvifi_Wait = new  WSCvifield(Misdial_ConfigMisc,"Misvifi_Wait");
+      Misvifi_Wait->initialize();
+  Misvifi_Wait->setPropertyV(WSNusePixmap,(WSCbool)1);
+  Misvifi_Wait->setPropertyV(WSNname,"Misvifi_Wait");
+  Misvifi_Wait->setPropertyV(WSNvis,(WSCbool)1);
+  Misvifi_Wait->setPropertyV(WSNx,(short)220);
+  Misvifi_Wait->setPropertyV(WSNy,(short)100);
+  Misvifi_Wait->setPropertyV(WSNanchorTop,(unsigned short)100);
+  Misvifi_Wait->setPropertyV(WSNanchorLeft,(unsigned short)220);
+  Misvifi_Wait->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
+  Misvifi_Wait->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
+    WSCprocedure* op_Misvifi_Wait_5 = new WSCprocedure("MisWaitIfiChg",3);
+    extern void MisWaitIfiChg(WSCbase*);
+    op_Misvifi_Wait_5->setFunction(MisWaitIfiChg,"MisWaitIfiChg");
+    Misvifi_Wait->addProcedure(op_Misvifi_Wait_5);
+
+  Misvsli_Wait = new  WSCvslider(Misdial_ConfigMisc,"Misvsli_Wait");
+      Misvsli_Wait->initialize();
+  Misvsli_Wait->setPropertyV(WSNsliderSize,(unsigned short)20);
+  Misvsli_Wait->setPropertyV(WSNminimum,(short)1);
+  Misvsli_Wait->setPropertyV(WSNdragInterval,(unsigned short)1);
+  Misvsli_Wait->setPropertyV(WSNvalue,(short)26);
+  Misvsli_Wait->setPropertyV(WSNname,"Misvsli_Wait");
+  Misvsli_Wait->setPropertyV(WSNvis,(WSCbool)1);
+  Misvsli_Wait->setPropertyV(WSNx,(short)320);
+  Misvsli_Wait->setPropertyV(WSNy,(short)100);
+  Misvsli_Wait->setPropertyV(WSNwidth,(unsigned short)160);
+  Misvsli_Wait->setPropertyV(WSNanchorTop,(unsigned short)100);
+  Misvsli_Wait->setPropertyV(WSNanchorLeft,(unsigned short)320);
+  Misvsli_Wait->setPropertyV(WSNanchorRight,(unsigned short)20);
+  Misvsli_Wait->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
+  Misvsli_Wait->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
+  Misvsli_Wait->setPropertyV(WSNanchorRightFlag,(WSCbool)1);
+    WSCprocedure* op_Misvsli_Wait_5 = new WSCprocedure("MisWaitSliChg",3);
+    extern void MisWaitSliChg(WSCbase*);
+    op_Misvsli_Wait_5->setFunction(MisWaitSliChg,"MisWaitSliChg");
+    Misvsli_Wait->addProcedure(op_Misvsli_Wait_5);
+
+  Miscomb_Language = new  WSCcomboBox(Misdial_ConfigMisc,"Miscomb_Language");
+      Miscomb_Language->initialize();
+  Miscomb_Language->setPropertyV(WSNbackBlinkColor,"DEF13");
+  Miscomb_Language->setPropertyV(WSNworkBackColor,"DEF11");
+  Miscomb_Language->setPropertyV(WSNname,"Miscomb_Language");
+  Miscomb_Language->setPropertyV(WSNx,(short)220);
+  Miscomb_Language->setPropertyV(WSNy,(short)140);
+  Miscomb_Language->setPropertyV(WSNwidth,(unsigned short)260);
+  Miscomb_Language->setPropertyV(WSNvis,(WSCbool)1);
+  Miscomb_Language->setPropertyV(WSNanchorTop,(unsigned short)140);
+  Miscomb_Language->setPropertyV(WSNanchorLeft,(unsigned short)220);
+  Miscomb_Language->setPropertyV(WSNanchorRight,(unsigned short)20);
+  Miscomb_Language->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
+  Miscomb_Language->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
+  Miscomb_Language->setPropertyV(WSNanchorRightFlag,(WSCbool)1);
+
+  Misvlab_Language = new  WSCvlabel(Misdial_ConfigMisc,"Misvlab_Language");
+      Misvlab_Language->initialize();
+  Misvlab_Language->setPropertyV(WSNusePixmap,(WSCbool)1);
+  Misvlab_Language->setPropertyV(WSNlabelString,"Language");
+  Misvlab_Language->setPropertyV(WSNname,"Misvlab_Language");
+  Misvlab_Language->setPropertyV(WSNvis,(WSCbool)1);
+  Misvlab_Language->setPropertyV(WSNx,(short)20);
+  Misvlab_Language->setPropertyV(WSNy,(short)140);
+  Misvlab_Language->setPropertyV(WSNwidth,(unsigned short)200);
+  Misvlab_Language->setPropertyV(WSNanchorTop,(unsigned short)140);
+  Misvlab_Language->setPropertyV(WSNanchorLeft,(unsigned short)20);
+  Misvlab_Language->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
+  Misvlab_Language->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
+
    MainWin->setVisible(True);
    return MainWin;
 }
