@@ -66,5 +66,17 @@ extern WSCvlabel* Cnfvlab_SkipArt;
 extern WSCvslider* Cnfvsli_SkipArt;
 extern WSCvifield* Cnfvifi_SkipArt;
 extern WSCvtimer* Maivtim_ReloadTimer;
+extern WSCdialog* Misdial_ConfigMisc;
+extern WSCvlabel* Misvlab_Chars;
+extern WSCvifield* Misvifi_Chars;
+extern WSCvslider* Misvsli_Chars;
+extern WSCvlabel* Misvlab_Speed;
+extern WSCvifield* Misvifi_Speed;
+extern WSCvslider* Misvsli_Speed;
+extern WSCvlabel* Misvlab_Wait;
+extern WSCvifield* Misvifi_Wait;
+extern WSCvslider* Misvsli_Wait;
+extern WSCcomboBox* Miscomb_Language;
+extern WSCvlabel* Misvlab_Language;
 
 #endif /* _MainWin_H */
