@@ -15,11 +15,9 @@ extern unsigned short gMainWinHeight;
 //----------------------------------------------------------
 void MainWinFixSize(WSCbase* object){
   //do something...
-#if 0
-//@@@
 	unsigned short h = object->getProperty( WSNheight );
+
 	if( h > gMainWinHeight )
 		object->setProperty( WSNheight, gMainWinHeight );
-#endif
 }
 static WSCfunctionRegister  op("MainWinFixSize",(void*)MainWinFixSize);
