@@ -21,7 +21,7 @@
 	{ NMesLabelBar,
 		"BAR" },
 
-	/* Config win label */
+	/* Config URL win label */
 
 	{ NMesLabelName,
 		"Name" },
@@ -52,6 +52,24 @@
 	{ NMesLabelBottom,
 		"Bottom" },
 
+	/* Config Misc win label */
+
+	{ NMesLabelChars,
+		"Scroll characters" },
+	{ NMesLabelSpeed,
+		"Scroll speed" },
+	{ NMesLabelWait,
+		"Wait" },
+	{ NMesLabelLanguage,
+		"Language" },
+
+	/* Language */
+
+	{ NMesLanguageEnglish,
+		"English" },
+	{ NMesLanguageJapanese,
+		"Japanese" },
+
 	/* Socket */
 
 	{ NMesRecvSrvrError,
@@ -99,6 +117,8 @@
 		"I can't save config file." },
 	{ NMesLoadVerError,
 		"I can't correspond save config file." },
+	{ NMesLoadMiscError,
+		"I found error from config file." },
 
 	/* URL name list */
 
