@@ -21,7 +21,7 @@
 	{ NMesLabelBar,
 		"̾" },
 
-	/* Config win label */
+	/* Config URL win label */
 
 	{ NMesLabelName,
 		"̾" },
@@ -52,6 +52,24 @@
 	{ NMesLabelBottom,
 		"" },
 
+	/* Config Misc win label */
+
+	{ NMesLabelChars,
+		"ʸ" },
+	{ NMesLabelSpeed,
+		"®" },
+	{ NMesLabelWait,
+		"볫ϻ" },
+	{ NMesLabelLanguage,
+		"" },
+
+	/* Language */
+
+	{ NMesLanguageEnglish,
+		"Ѹ" },
+	{ NMesLanguageJapanese,
+		"ܸ" },
+
 	/* Socket */
 
 	{ NMesRecvSrvrError,
@@ -99,6 +117,8 @@
 		"ե˽񤭽ФޤǤ" },
 	{ NMesLoadVerError,
 		"ե뤬бƤʤСǤ" },
+	{ NMesLoadMiscError,
+		"եν񼰤ְäƤޤ" },
 
 	/* URL name list */
 
