@@ -17,7 +17,10 @@ typedef enum {
 
 /**/
 
-void ResetMessage( ELangKind nLang );
+void SetMessage( ELangKind nLang );
+void SetMessage( WSCstring strLang );
+ELangKind GetLangKind( void );
+void SetLabel( void );
 
 void PopupError( WSCstring str );
 void PopupWarning( WSCstring str );
