@@ -4,8 +4,12 @@
 void InitSrvr( void );
 int OpenSrvr( WSCstring url, WSCstring port, int portN );
 int CloseSrvr( int sock );
-bool RecvSrvr( int sock, WSCstring url, WSCstring *dst );
-bool RecvLine( int sock, WSCstring *dst );
+
+bool RecvSrvr(
+	int sock, const WSCstring url, WSCstring *dst,
+	long encoding );
+bool RecvLine( int sock, WSCstring *dst, long encoding );
+
 WSCstring ConvUrlToPath( WSCstring url );
 WSCstring ConvUrlToHost( WSCstring url );
 
